(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     82088,       2327]*)
(*NotebookOutlinePosition[    128846,       3856]*)
(*  CellTagsIndexPosition[    128802,       3852]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["QANotations.nb", "Section",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[CellGroupData[{

Cell["Save Line And Reset History", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(QuantumAlgebra`QuantumAlgebra`Private`linenumber = $Line;\)\)], \
"Input"],

Cell[BoxData[
    \(\($HistoryLength = 1;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Open QAMessage", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(NotebookWrite[
        QuantumAlgebra`QuantumAlgebra`Private`nb3, \[IndentingNewLine]Cell[
          TextData[\[IndentingNewLine]{StyleBox["\<Loading QuantumAlgebra \
notations.\>", \[IndentingNewLine]FontSize \[Rule] \ 
                  14, \[IndentingNewLine]FontSlant \[Rule] 
                  Italic]}\ ], "\<Text\>", \[IndentingNewLine]\t
          Editable \[Rule] False, \[IndentingNewLine]\t
          CellDingbat \[Rule] "\<\[WatchIcon]\>", \[IndentingNewLine]\t
          CellMargins \[Rule] {{35, 0}, {5, 10}}], \ All];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set QuantumAlgebra Context", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(\(BeginPackage["\<QuantumAlgebra`QuantumAlgebra`\>"];\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    \(BraArgs; \ KetArgs; \ BraKetArgs; \ UDScript;\)], "Input"],

Cell[BoxData[
    \(\(Begin["\<`Private`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(Off[General::spell];\)\)], "Input"],

Cell[BoxData[
    \(\(Off[General::spell1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reset Flags And Load Notation.m", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(Utilities`Notation`AutoLoadNotationPalette = False;\)\)], "Input"],

Cell[BoxData[
    \(\(Utilities`Notation`AutoUpdateNotationStyleSheet = False;\)\)], "Input"],

Cell[BoxData[
    \(\(Needs["\<Utilities`Notation`\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implement New Styles", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(QAStyles := 
        Cell[CellGroupData[{Cell["\<Bra Ket Styles\>", "\<Section\>"], 
              Cell[\*"\"\<\\< The cells below define certain styles needed \
for defining Bras&Kets.These styles serve to give the correct structural \
properties to Bras & Kets \\>\>\"", "\<Text\>", 
                CellTags \[Rule] "\<NotationPackage35\>"], 
              Cell[StyleData["\<BraKetArg\>"], \
\[IndentingNewLine]AutoStyleOptions \[Rule] {"\<UnmatchedBracketStyle\>" \
\[Rule] "\<UnmatchedBracket\>"}, \[IndentingNewLine]SpanMinSize \[Rule] 
                  Automatic, \[IndentingNewLine]StyleMenuListing \[Rule] 
                  None, \[IndentingNewLine]AdjustmentBoxOptions \[Rule] \
{BoxMargins \[Rule] {{0, 0}, {0, 0}}}, 
                TagBoxOptions \[Rule] {Editable \[Rule] True, 
                    Selectable \[Rule] True}], 
              Cell[StyleData["\<BraWrapper\>"], \
\[IndentingNewLine]AutoStyleOptions \[Rule] {"\<UnmatchedBracketStyle\>" \
\[Rule] None}, \[IndentingNewLine]SpanMinSize \[Rule] 
                  2, \[IndentingNewLine]ScriptBaselineShifts \[Rule] {0.6, 
                    0.9}, \[IndentingNewLine]StyleMenuListing \[Rule] 
                  None, \[IndentingNewLine]AdjustmentBoxOptions \[Rule] \
{BoxMargins \[Rule] {{0.2, \(-0.13\)}, {0, 0}}}, 
                TagBoxOptions \[Rule] {Editable \[Rule] False}], 
              Cell[StyleData["\<KetWrapper\>"], \
\[IndentingNewLine]AutoStyleOptions \[Rule] {"\<UnmatchedBracketStyle\>" \
\[Rule] None}, \[IndentingNewLine]SpanMinSize \[Rule] 
                  2, \[IndentingNewLine]ScriptBaselineShifts \[Rule] {0.6, 
                    0.9}, \[IndentingNewLine]StyleMenuListing \[Rule] 
                  None, \[IndentingNewLine]AdjustmentBoxOptions \[Rule] \
{BoxMargins \[Rule] {{\(-0.1\), 0.2}, {0, 
                          0}}}, \[IndentingNewLine]TagBoxOptions \[Rule] \
{Editable \[Rule] False}], 
              Cell[StyleData["\<BraKetWrapper\>"], \
\[IndentingNewLine]AutoStyleOptions \[Rule] {"\<UnmatchedBracketStyle\>" \
\[Rule] None}, \[IndentingNewLine]SpanMinSize \[Rule] 
                  2, \[IndentingNewLine]ScriptBaselineShifts \[Rule] {0.6, 
                    0.9}, \[IndentingNewLine]StyleMenuListing \[Rule] 
                  None, \[IndentingNewLine]AdjustmentBoxOptions \[Rule] \
{BoxMargins \[Rule] {{0.25, 0.25}, {0, 0}}}, 
                TagBoxOptions \[Rule] {Editable \[Rule] False}], 
              Cell[StyleData["\<RIndex\>"], \
\[IndentingNewLine]StyleMenuListing \[Rule] 
                  None, \[IndentingNewLine]AdjustmentBoxOptions \[Rule] \
{BoxMargins \[Rule] {{\(-0.16\), 0}, {0, 
                          0}}}, \[IndentingNewLine]TagBoxOptions \[Rule] \
{Editable \[Rule] False}], \[IndentingNewLine]Cell[
                StyleData["\<LIndex\>"], \[IndentingNewLine]StyleMenuListing \
\[Rule] None, \[IndentingNewLine]AdjustmentBoxOptions \[Rule] {BoxMargins \
\[Rule] {{0, \(-0.1\)}, {0, 
                          0}}}, \[IndentingNewLine]TagBoxOptions \[Rule] \
{Editable \[Rule] False}]}, Closed]];\)\)], "Input"],

Cell[BoxData[
    \(\(Utilities`Notation`Private`AddStylesToNotebook[QAStyles, 
        nb1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define Some Box Structures", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(Unprotect@SubscriptBox;\)\)], "Input"],

Cell[BoxData[
    \(SubscriptBox[RowBox[{x_, "\<[\>", RowBox[y_], "\<]\>"}], "\<-\>"] := 
      RowBox[{x, "\< \>", 
          SubscriptBox[
            RowBox[{"\<[\>", RowBox[y], "\<]\>"}], "\<-\>"]}]\)], "Input"],

Cell[BoxData[
    \(\(Protect@SubscriptBox;\)\)], "Input"],

Cell[BoxData[
    \(\(Unprotect@RowBox;\)\)], "Input"],

Cell[BoxData[
    \(\(RowBox[{"\<(\>", TagBox[arg_, Ket, opts___], "\<)\>"}] := 
        TagBox[arg, Ket, opts];\)\)], "Input"],

Cell[BoxData[
    \(\(RowBox[{"\<(\>", TagBox[arg_, Bra, `opts___], "\<)\>"}] := 
        TagBox[arg, Bra, opts];\)\)], "Input"],

Cell[BoxData[
    \(\(RowBox[{"\<(\>", TagBox[arg_, Braket, \ opts___], "\<)\>"}] := 
        TagBox[\ arg, Braket, \ opts];\)\)], "Input"],

Cell[BoxData[
    \(\(Protect@RowBox;\)\)], "Input"],

Cell[BoxData[
    \(\(Unprotect@FullForm;\)\)], "Input"],

Cell[BoxData[
    \(\(FullForm /: 
        TagBox[StyleBox[expr_, Verbatim[ShowSpecialCharacters \[Rule] False], 
            rest__], FullForm] := 
        TagBox[StyleBox[expr, rest], FullForm];\)\)], "Input"],

Cell[BoxData[
    \(\(Protect@FullForm;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notations", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              AdjustmentBox["\[VerticalSeparator]",
                BoxMargins->{{-0.4, 0}, {0, 0}}], 
              AdjustmentBox[
                TagBox["\[Psi]___",
                  KetArgs,
                  TagStyle->"BraKetArg"],
                BoxBaselineShift->0], "\[RightAngleBracket]"}],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle",
          Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Ket[\[Psi]___]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle",
          Editable->True]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{"\[LeftAngleBracket]", 
              AdjustmentBox[
                TagBox["\[Psi]___",
                  BraArgs,
                  TagStyle->"BraKetArg"],
                BoxBaselineShift->0], 
              AdjustmentBox["\[VerticalSeparator]",
                BoxMargins->{{0, -0.2}, {0, 0}}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle",
          Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Bra[\[Psi]___]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle",
          Editable->True]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{"\[LeftAngleBracket]", 
              AdjustmentBox[
                RowBox[{
                  TagBox["\[Psi]__",
                    BraKetArgs,
                    TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                  TagBox["\[Phi]__",
                    BraKetArgs,
                    TagStyle->"BraKetArg"]}],
                BoxBaselineShift->0], "\[RightAngleBracket]"}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle",
          Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__}, {\[Phi]__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle",
          Editable->True]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubscriptBox[
              RowBox[{
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{-0.4, 0}, {0, 0}}], 
                AdjustmentBox[
                  TagBox["\[Psi]__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["x__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Ket[\[Psi]__, {x__}, {}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SuperscriptBox[
              RowBox[{
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{-0.4, 0}, {0, 0}}], 
                AdjustmentBox[
                  TagBox["\[Psi]__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["x__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Ket[\[Psi]__, {}, {x__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubsuperscriptBox[
              RowBox[{
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{-0.4, 0}, {0, 0}}], 
                AdjustmentBox[
                  TagBox["\[Psi]__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["x__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"], 
              TagBox[
                AdjustmentBox[
                  TagBox["y__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Ket[\[Psi]__, {x__}, {y__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  TagBox["\[Psi]__",
                    BraArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], 
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Bra[\[Psi]__, {x__}, {}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  TagBox["\[Psi]__",
                    BraArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], 
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Bra[\[Psi]__, {}, {x__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  TagBox["\[Psi]__",
                    BraArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], 
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Bra[\[Psi]__, {x__}, {y__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[Psi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[Phi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["x1__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__}, {\[Phi]__, {x1__}, {}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[Psi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[Phi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["y1__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__}, {\[Phi]__, {}, {y1__}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[Psi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[Phi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["x1__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"], 
              TagBox[
                AdjustmentBox[
                  TagBox["y1__",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__}, {\[Phi]__, {x1__}, {y1__}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[Psi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[Phi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {}}, {\[Phi]__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[Psi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[Phi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {}, {y2__}}, {\[Phi]__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[Psi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[Phi]__",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {y2__}}, {\[Phi]__}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["x1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {}}, {\[Phi]__, {x1__}, {}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {}}, {\[Phi]__, {}, {y1__}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["x1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {}}, {\[Phi]__, {x1__}, {y1__}}]\),
          
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["x1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {}, {y2__}}, {\[Phi]__, {x1__}, {}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {}, {y2__}}, {\[Phi]__, {}, {y1__}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["x1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {}, {y2__}}, {\[Phi]__, {x1__}, {y1__}}]\),
          
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["x1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {y2__}}, {\[Phi]__, {x1__}, {}}]\),
          
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {y2__}}, {\[Phi]__, {}, {y1__}}]\),
          
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["x2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y2__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[Psi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[Phi]__",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["x1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["y1__",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Braket[{\[Psi]__, {x2__}, {y2__}}, {\[Phi]__, {x1__}, \
{y1__}}]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\([A_, B_]\)\_-\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Commutator[A_, B_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(A_\&^\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Operator[A_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(x_\&^\^n__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Operator[x_, {}, {n__}]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(x_\&^\_m__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Operator[x_, {m__}, {}]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Notation", "[", 
          RowBox[{
            TagBox[\(\(x_\&^\)\_m__\%n__\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"], " ", 
            "\[DoubleLongLeftRightArrow]", " ", 
            TagBox[\(Operator[x_, {m__}, {n__}]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}], 
      "  "}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Notation", "[", 
          RowBox[{
            TagBox[\(\(A_\&^\)\_x__\%\[Dagger]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"], " ", 
            "\[DoubleLongLeftRightArrow]", " ", 
            TagBox[\(Operator[A_, "\<H\>", {x__}, {}]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}], 
      "  "}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(A_\&^\^\[Dagger]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Operator[A_, "\<H\>"]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Notation", "[", 
          RowBox[{
            TagBox[\(A_\&^\^\(y__, \[Dagger]\)\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"], " ", 
            "\[DoubleLongLeftRightArrow]", " ", 
            TagBox[\(Operator[A_, "\<H\>", {}, {y__}]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}], 
      "  "}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Notation", "[", 
          RowBox[{
            TagBox[\(\(A_\&^\)\_x__\%\(y__, \[Dagger]\)\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"], " ", 
            "\[DoubleLongLeftRightArrow]", " ", 
            TagBox[\(Operator[A_, "\<H\>", {x__}, {y__}]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}], 
      "  "}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          SuperscriptBox[
            TagBox[\(f_?AtomQ\),
              NotationPatternTag,
              TagStyle->"NotationPatternWrapperStyle"], "*"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[
          RowBox[{"Conjugate", "[", 
            TagBox[\(f_?AtomQ\),
              NotationPatternTag,
              TagStyle->"NotationPatternWrapperStyle"], "]"}],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                TagBox[\(f_?\((\(! AtomQ[#]\) &)\)\),
                  NotationPatternTag,
                  TagStyle->"NotationPatternWrapperStyle"], ")"}], "*"], 
            " "}],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[
          RowBox[{"Conjugate", "[", 
            TagBox[\(f_?\((\(! AtomQ[#]\) &)\)\),
              NotationPatternTag,
              TagStyle->"NotationPatternWrapperStyle"], "]"}],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          SuperscriptBox[
            TagBox[\(P_?OperatorQ\),
              NotationPatternTag,
              TagStyle->"NotationPatternWrapperStyle"], 
            TagBox[\(n_?Negative\),
              NotationPatternTag,
              TagStyle->"NotationPatternWrapperStyle"]],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[
          RowBox[{"Power", "[", 
            RowBox[{
              TagBox[\(P_?OperatorQ\),
                NotationPatternTag,
                TagStyle->"NotationPatternWrapperStyle"], ",", 
              TagBox[\(n_?Negative\),
                NotationPatternTag,
                TagStyle->"NotationPatternWrapperStyle"]}], "]"}],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[
          RowBox[{"c_", " ", 
            SuperscriptBox[
              TagBox[\(P_?OperatorQ\),
                NotationPatternTag,
                TagStyle->"NotationPatternWrapperStyle"], 
              TagBox[\(n_?Negative\),
                NotationPatternTag,
                TagStyle->"NotationPatternWrapperStyle"]]}],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[
          RowBox[{"Times", "[", 
            RowBox[{"c_", ",", 
              RowBox[{"Power", "[", 
                RowBox[{
                  TagBox[\(P_?OperatorQ\),
                    NotationPatternTag,
                    TagStyle->"NotationPatternWrapperStyle"], ",", 
                  TagBox[\(n_?Negative\),
                    NotationPatternTag,
                    TagStyle->"NotationPatternWrapperStyle"]}], "]"}]}], 
            "]"}],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Infix Notations", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    RowBox[{"InfixNotation", "[", 
      RowBox[{
        TagBox["\[CenterDot]",
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "NonCommutativeMultiply"}],
       "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Braket[a]\)], "Input"],

Cell[BoxData[
    \(Braket[a]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Add Input Aliases", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    RowBox[{
      RowBox[{"AddInputAlias", "[", 
        RowBox[{
          TagBox[\(\([\[SelectionPlaceholder]]\)\_-\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], ",", "\"\<com\>\"", ",", 
          "nb1"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AddInputAlias", "[", 
        RowBox[{
          TagBox[\(\[SelectionPlaceholder]\&^\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], ",", "\"\<op\>\"", ",", 
          "nb1"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AddInputAlias", "[", 
        RowBox[{
          TagBox[\(\[SelectionPlaceholder]\&^\^\[Dagger]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], ",", "\"\<hop\>\"", ",", 
          "nb1"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              AdjustmentBox["\[VerticalSeparator]",
                BoxMargins->{{-0.4, 0}, {0, 0}}], 
              AdjustmentBox[
                TagBox["\[SelectionPlaceholder]",
                  KetArgs,
                  TagStyle->"BraKetArg"],
                BoxBaselineShift->0], "\[RightAngleBracket]"}],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ket\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{"\[LeftAngleBracket]", 
              AdjustmentBox[
                TagBox["\[SelectionPlaceholder]",
                  BraArgs,
                  TagStyle->"BraKetArg"],
                BoxBaselineShift->0], 
              AdjustmentBox["\[VerticalSeparator]",
                BoxMargins->{{0, -0.2}, {0, 0}}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<bra\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{"\[LeftAngleBracket]", 
              AdjustmentBox[
                RowBox[{
                  TagBox["\[SelectionPlaceholder]",
                    BraKetArgs,
                    TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                  TagBox["\[SelectionPlaceholder]",
                    BraKetArgs,
                    TagStyle->"BraKetArg"]}],
                BoxBaselineShift->0], "\[RightAngleBracket]"}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<braket\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubscriptBox[
              RowBox[{
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{-0.4, 0}, {0, 0}}], 
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ketd\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SuperscriptBox[
              RowBox[{
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{-0.4, 0}, {0, 0}}], 
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ketu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubsuperscriptBox[
              RowBox[{
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{-0.4, 0}, {0, 0}}], 
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Ket,
            TagStyle->"KetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ketdu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    BraArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], 
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dbra\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    BraArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], 
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ubra\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    BraArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0], 
                AdjustmentBox["\[VerticalSeparator]",
                  BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
            Bra,
            TagStyle->"BraWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dubra\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<braketu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<braketu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            SubsuperscriptBox[
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"], 
              TagBox[
                AdjustmentBox[
                  TagBox["\[SelectionPlaceholder]",
                    KetArgs,
                    TagStyle->"BraKetArg"],
                  BoxBaselineShift->0],
                UDScript,
                TagStyle->"RIndex"]],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<braketdu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dbraket\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ubraket\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              RowBox[{"\[LeftAngleBracket]", 
                AdjustmentBox[
                  RowBox[{
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                    TagBox["\[SelectionPlaceholder]",
                      BraKetArgs,
                      TagStyle->"BraKetArg"]}],
                  BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dubraket\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dbraketd\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dbraketu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dbraketdu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ubraketd\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ubraketu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<ubraketdu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dubraketd\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dubraketu\>\"", ",", 
        "nb1"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"AddInputAlias", "[", 
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"LIndex"]], 
              SubsuperscriptBox[
                RowBox[{"\[LeftAngleBracket]", 
                  AdjustmentBox[
                    RowBox[{
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"], "\[VerticalSeparator]", 
                      TagBox["\[SelectionPlaceholder]",
                        BraKetArgs,
                        TagStyle->"BraKetArg"]}],
                    BoxBaselineShift->0], "\[RightAngleBracket]"}], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"], 
                TagBox[
                  AdjustmentBox[
                    TagBox["\[SelectionPlaceholder]",
                      BraArgs,
                      TagStyle->"BraKetArg"],
                    BoxBaselineShift->0],
                  UDScript,
                  TagStyle->"RIndex"]]}],
            Braket,
            TagStyle->"BraKetWrapper"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "\"\<dubraketdu\>\"", ",", 
        "nb1"}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reset Flags And End QuantumAlgebra Context", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\(Utilities`Notation`AutoLoadNotationPalette = True;\)\)], "Input"],

Cell[BoxData[
    \(\(Utilities`Notation`AutoUpdateNotationStyleSheet = True;\)\)], "Input"],

Cell[BoxData[
    \(\(End[];\)\)], "Input"],

Cell[BoxData[
    \(\(EndPackage[];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Close Notebooks And Reset Line and History", "Subsubsection",
  FontColor->RGBColor[0, 0.250004, 0.500008]],

Cell[BoxData[
    \(\({\ \ \(NotebookClose[
            QuantumAlgebra`QuantumAlgebra`Private`nb3];\), \
\[IndentingNewLine]\($HistoryLength =. ;\), \[IndentingNewLine]\($Line = 
            QuantumAlgebra`QuantumAlgebra`Private`linenumber - 
              1;\), \[IndentingNewLine]\(NotebookClose[
            QuantumAlgebra`QuantumAlgebra`Private`nb2];\)};\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 536}},
WindowSize->{792, 503},
WindowMargins->{{0, Automatic}, {Automatic, -3}},
Visible->True,
InputAliases->{
  "op"->OverscriptBox[ "\[SelectionPlaceholder]", "^"], 
    "hop"->SuperscriptBox[ 
        OverscriptBox[ "\[SelectionPlaceholder]", "^"], "\[Dagger]"], 
    "braket"->TagBox[ 
        RowBox[ {"\[LeftAngleBracket]", 
          AdjustmentBox[ 
            RowBox[ {
              TagBox[ "\[Placeholder]", BraKetArgs, TagStyle -> "BraKetArg"], 
              "\[VerticalSeparator]", 
              TagBox[ 
              "\[Placeholder]", BraKetArgs, TagStyle -> "BraKetArg"]}], 
            BoxBaselineShift -> 0.0], "\[RightAngleBracket]"}], BraKet, 
        TagStyle -> "BraKetWrapper"], "com"->SubscriptBox[ 
        RowBox[ {"[", "\[SelectionPlaceholder]", "]"}], "-"], "ket"->TagBox[ 
        RowBox[ {"\[VerticalSeparator]", 
          AdjustmentBox[ 
            TagBox[ "\[Placeholder]", KetArgs, TagStyle -> "BraKetArg"], 
            BoxBaselineShift -> 0.0], "\[RightAngleBracket]"}], Ket, TagStyle -> 
        "KetWrapper"], "bra"->TagBox[ 
        RowBox[ {"\[LeftAngleBracket]", 
          RowBox[ {
            AdjustmentBox[ 
              TagBox[ "\[Placeholder]", BraArgs, TagStyle -> "BraKetArg"], 
              BoxBaselineShift -> 0.0], "\[VerticalSeparator]"}]}], Bra, 
        TagStyle -> "BraWrapper"], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{59, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{108, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{158, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display of certain \
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" \
style defines how unmatched bracket, curly bracket, and parenthesis \
characters are displayed (typically by coloring them to make them stand out).\
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Bra Ket Styles", "Section"],
  
  Cell["\<\
   The cells below define certain styles needed for    defining Bras&Kets. \
These styles serve to give the correct    structural properties to Bras & \
Kets   \
\>", "Text",
    CellTags->"NotationPackage35"],
  
  Cell[StyleData["BraKetArg"],
    AutoStyleOptions->{"UnmatchedBracketStyle"->"UnmatchedBracket"},
    SpanMinSize->Automatic,
    StyleMenuListing->None,
    AdjustmentBoxOptions->{BoxMargins->{{0, 0}, {0, 0}}},
    TagBoxOptions->{Editable->True,
    Selectable->True}],
  
  Cell[StyleData["BraWrapper"],
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    ScriptBaselineShifts->{0.6, 0.9},
    SpanMinSize->2,
    StyleMenuListing->None,
    AdjustmentBoxOptions->{BoxMargins->{{0.2, -0.13}, {0, 0}}},
    TagBoxOptions->{Editable->False}],
  
  Cell[StyleData["KetWrapper"],
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    ScriptBaselineShifts->{0.6, 0.9},
    SpanMinSize->2,
    StyleMenuListing->None,
    AdjustmentBoxOptions->{BoxMargins->{{-0.1, 0.2}, {0, 0}}},
    TagBoxOptions->{Editable->False}],
  
  Cell[StyleData["BraKetWrapper"],
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    ScriptBaselineShifts->{0.6, 0.9},
    SpanMinSize->2,
    StyleMenuListing->None,
    AdjustmentBoxOptions->{BoxMargins->{{0.25, 0.25}, {0, 0}}},
    TagBoxOptions->{Editable->False}],
  
  Cell[StyleData["LIndex"],
    StyleMenuListing->None,
    AdjustmentBoxOptions->{BoxMargins->{{0, -0.1}, {0, 0}}},
    TagBoxOptions->{Editable->False}],
  
  Cell[StyleData["RIndex"],
    StyleMenuListing->None,
    AdjustmentBoxOptions->{BoxMargins->{{-0.16, 0}, {0, 0}}},
    TagBoxOptions->{Editable->False}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 79, 1, 59, "Section"],

Cell[CellGroupData[{
Cell[1880, 58, 98, 1, 43, "Subsubsection"],
Cell[1981, 61, 96, 2, 30, "Input"],
Cell[2080, 65, 56, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2173, 71, 85, 1, 43, "Subsubsection"],
Cell[2261, 74, 569, 9, 170, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2867, 88, 97, 1, 43, "Subsubsection"],
Cell[2967, 91, 100, 2, 30, "Input"],
Cell[3070, 95, 78, 1, 30, "Input"],
Cell[3151, 98, 60, 1, 30, "Input"],
Cell[3214, 101, 57, 1, 30, "Input"],
Cell[3274, 104, 58, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3369, 110, 102, 1, 43, "Subsubsection"],
Cell[3474, 113, 88, 1, 30, "Input"],
Cell[3565, 116, 93, 1, 30, "Input"],
Cell[3661, 119, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3768, 125, 91, 1, 43, "Subsubsection"],
Cell[3862, 128, 3089, 50, 790, "Input"],
Cell[6954, 180, 108, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7099, 187, 97, 1, 43, "Subsubsection"],
Cell[7199, 190, 60, 1, 30, "Input"],
Cell[7262, 193, 215, 4, 50, "Input"],
Cell[7480, 199, 58, 1, 30, "Input"],
Cell[7541, 202, 54, 1, 30, "Input"],
Cell[7598, 205, 127, 2, 30, "Input"],
Cell[7728, 209, 128, 2, 30, "Input"],
Cell[7859, 213, 139, 2, 30, "Input"],
Cell[8001, 217, 52, 1, 30, "Input"],
Cell[8056, 220, 56, 1, 30, "Input"],
Cell[8115, 223, 211, 4, 50, "Input"],
Cell[8329, 229, 54, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8420, 235, 80, 1, 43, "Subsubsection"],
Cell[8503, 238, 760, 21, 31, "Input"],
Cell[9266, 261, 759, 21, 31, "Input"],
Cell[10028, 284, 875, 23, 31, "Input"],
Cell[10906, 309, 1031, 29, 34, "Input"],
Cell[11940, 340, 1033, 29, 31, "Input"],
Cell[12976, 371, 1301, 37, 34, "Input"],
Cell[14280, 410, 1103, 30, 34, "Input"],
Cell[15386, 442, 1105, 30, 31, "Input"],
Cell[16494, 474, 1389, 38, 34, "Input"],
Cell[17886, 514, 1154, 31, 34, "Input"],
Cell[19043, 547, 1156, 31, 31, "Input"],
Cell[20202, 580, 1426, 39, 34, "Input"],
Cell[21631, 621, 1227, 32, 34, "Input"],
Cell[22861, 655, 1229, 32, 31, "Input"],
Cell[24093, 689, 1515, 40, 34, "Input"],
Cell[25611, 731, 1567, 41, 34, "Input"],
Cell[27181, 774, 1569, 41, 34, "Input"],
Cell[28753, 817, 1866, 50, 36, "Input"],
Cell[30622, 869, 1569, 41, 34, "Input"],
Cell[32194, 912, 1571, 41, 31, "Input"],
Cell[33768, 955, 1868, 50, 34, "Input"],
Cell[35639, 1007, 1866, 50, 36, "Input"],
Cell[37508, 1059, 1868, 50, 34, "Input"],
Cell[39379, 1111, 2145, 58, 34, "Input"],
Cell[41527, 1171, 385, 10, 30, "Input"],
Cell[41915, 1183, 369, 10, 31, "Input"],
Cell[42287, 1195, 385, 10, 30, "Input"],
Cell[42675, 1207, 385, 10, 34, "Input"],
Cell[43063, 1219, 445, 12, 34, "Input"],
Cell[43511, 1233, 457, 12, 35, "Input"],
Cell[43971, 1247, 389, 10, 32, "Input"],
Cell[44363, 1259, 457, 12, 32, "Input"],
Cell[44823, 1273, 469, 12, 35, "Input"],
Cell[45295, 1287, 626, 17, 30, "Input"],
Cell[45924, 1306, 748, 20, 30, "Input"],
Cell[46675, 1328, 919, 24, 31, "Input"],
Cell[47597, 1354, 1084, 28, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48718, 1387, 86, 1, 43, "Subsubsection"],
Cell[48807, 1390, 223, 6, 30, "Input"],

Cell[CellGroupData[{
Cell[49055, 1400, 42, 1, 30, "Input"],
Cell[49100, 1403, 43, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49192, 1410, 88, 1, 43, "Subsubsection"],
Cell[49283, 1413, 280, 7, 30, "Input"],
Cell[49566, 1422, 273, 7, 30, "Input"],
Cell[49842, 1431, 285, 7, 31, "Input"],
Cell[50130, 1440, 619, 17, 31, "Input"],
Cell[50752, 1459, 618, 17, 31, "Input"],
Cell[51373, 1478, 737, 19, 31, "Input"],
Cell[52113, 1499, 945, 26, 31, "Input"],
Cell[53061, 1527, 947, 26, 31, "Input"],
Cell[54011, 1555, 1233, 34, 31, "Input"],
Cell[55247, 1591, 1017, 27, 31, "Input"],
Cell[56267, 1620, 1019, 27, 31, "Input"],
Cell[57289, 1649, 1321, 35, 31, "Input"],
Cell[58613, 1686, 1067, 28, 31, "Input"],
Cell[59683, 1716, 1069, 28, 31, "Input"],
Cell[60755, 1746, 1355, 36, 31, "Input"],
Cell[62113, 1784, 1140, 29, 31, "Input"],
Cell[63256, 1815, 1142, 29, 31, "Input"],
Cell[64401, 1846, 1444, 37, 31, "Input"],
Cell[65848, 1885, 1488, 38, 31, "Input"],
Cell[67339, 1925, 1490, 38, 31, "Input"],
Cell[68832, 1965, 1792, 46, 31, "Input"],
Cell[70627, 2013, 1490, 38, 31, "Input"],
Cell[72120, 2053, 1492, 38, 31, "Input"],
Cell[73615, 2093, 1794, 46, 31, "Input"],
Cell[75412, 2141, 1792, 46, 31, "Input"],
Cell[77207, 2189, 1794, 46, 31, "Input"],
Cell[79004, 2237, 2096, 54, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81137, 2296, 113, 1, 43, "Subsubsection"],
Cell[81253, 2299, 87, 1, 30, "Input"],
Cell[81343, 2302, 92, 1, 30, "Input"],
Cell[81438, 2305, 43, 1, 30, "Input"],
Cell[81484, 2308, 50, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81571, 2314, 113, 1, 43, "Subsubsection"],
Cell[81687, 2317, 373, 6, 90, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

